import network
import socket
from machine import I2C, Pin
from i2c_lcd import I2cLcd

# Wi-Fi details
SSID = "AV"           # Replace with your Wi-Fi network name
PASSWORD = "password" # Replace with your Wi-Fi password

# LCD setup
I2C_ADDR = 0x27  # Update this with your LCD's I2C address if different
i2c = I2C(0, sda=Pin(0), scl=Pin(1), freq=400000)
lcd = I2cLcd(i2c, I2C_ADDR, 2, 16)

# Connect to Wi-Fi
def connect_to_wifi():
    wlan = network.WLAN(network.STA_IF)
    wlan.active(True)
    wlan.connect(SSID, PASSWORD)
    
    print("Connecting to Wi-Fi...")
    while not wlan.isconnected():
        pass
    print("Connected!")
    print("IP address:", wlan.ifconfig()[0])
    return wlan.ifconfig()[0]  # Return the Pico W's IP address

# Start the web server
def start_server():
    addr = socket.getaddrinfo("0.0.0.0", 80)[0][-1]
    s = socket.socket()
    s.bind(addr)
    s.listen(1)
    print("Listening on:", addr)

    while True:
        cl, addr = s.accept()
        print("Client connected from:", addr)
        request = cl.recv(1024).decode()
        print("Request:", request)

        # Extract the message from the request
        if "GET /?message=" in request:
            try:
                message = request.split("GET /?message=")[1].split(" ")[0]
                message = message.replace("%20", " ")  # Decode spaces in URLs
                print("Message received:", message)
                
                # Display the message on the LCD
                lcd.clear()
                lcd.putstr(message[:16])  # Display the first 16 characters
                if len(message) > 16:
                    lcd.move_to(0, 1)
                    lcd.putstr(message[16:32])  # Display the next 16 characters
            except Exception as e:
                print("Error processing message:", e)

        # Send a response to the browser
        cl.send("HTTP/1.1 200 OK\r\n")
        cl.send("Content-Type: text/html\r\n\r\n")
        cl.send("""
            <!DOCTYPE html>
            <html>
            <body>
                <h1>Pico W LCD Server</h1>
                <form action="/">
                    <label for="message">Enter a message:</label><br>
                    <input type="text" id="message" name="message"><br><br>
                    <input type="submit" value="Send">
                </form>
            </body>
            </html>
        """)
        cl.close()

# Main function
try:
    ip = connect_to_wifi()  # Connect to Wi-Fi
    print("Web server running at http://" + ip)
    start_server()  # Start the web server
except KeyboardInterrupt:
    print("Server stopped.")
